@@ -16,9 +16,17 @@ class InputNode(Node):
     """
 
     def __init__(self, node_def: dict):
-        self._id = node_def.get('id')
+        Node.__init__(self, node_def)
+        self.is_evalutated = True
         self.targets = node_def.get('targets')
 
+    def run(
+        self,
+        path: ValidFlowPath,
+        payload: dict
+    ):
+        pass
+
 
 class OutputNode(Node):
     """
@@ -60,10 +68,17 @@ class OutputNode(Node):
         result = {}
         for pair in self.output:
             key = pair.get('key')
-            if pair.get('payload_element', False):
-                assert 'payload_key' in pair
-                result[key] = payload.get(pair.get('payload_key'))
+            if pair.get('payloadElement', False):
+                assert 'payloadKey' in pair
+                result[key] = payload.get(pair.get('payloadKey'))
             else:
-                assert 'literal_def' in pair
-                result[key] = pair.get('literal_def').get('value')
+                assert 'literalDef' in pair
+                result[key] = pair.get('literalDef').get('value')
         return result
+
+    def run(
+        self,
+        path: ValidFlowPath,
+        payload: dict
+    ):
+        pass
